pub struct fe_caps { /* private fields */ }Expand description
Frontend capabilities
Implementations
Sourceimpl fe_caps
impl fe_caps
Sourcepub const FE_IS_STUPID: Self
pub const FE_IS_STUPID: Self
There’s something wrong at the frontend, and it can’t report its capabilities
Sourcepub const FE_CAN_INVERSION_AUTO: Self
pub const FE_CAN_INVERSION_AUTO: Self
Can auto-detect frequency spectral band inversion
Sourcepub const FE_CAN_FEC_1_2: Self
pub const FE_CAN_FEC_1_2: Self
Supports FEC 1/2
Sourcepub const FE_CAN_FEC_2_3: Self
pub const FE_CAN_FEC_2_3: Self
Supports FEC 2/3
Sourcepub const FE_CAN_FEC_3_4: Self
pub const FE_CAN_FEC_3_4: Self
Supports FEC 3/4
Sourcepub const FE_CAN_FEC_4_5: Self
pub const FE_CAN_FEC_4_5: Self
Supports FEC 4/5
Sourcepub const FE_CAN_FEC_5_6: Self
pub const FE_CAN_FEC_5_6: Self
Supports FEC 5/6
Sourcepub const FE_CAN_FEC_6_7: Self
pub const FE_CAN_FEC_6_7: Self
Supports FEC 6/7
Sourcepub const FE_CAN_FEC_7_8: Self
pub const FE_CAN_FEC_7_8: Self
Supports FEC 7/8
Sourcepub const FE_CAN_FEC_8_9: Self
pub const FE_CAN_FEC_8_9: Self
Supports FEC 8/9
Sourcepub const FE_CAN_FEC_AUTO: Self
pub const FE_CAN_FEC_AUTO: Self
Can auto-detect FEC
Sourcepub const FE_CAN_QPSK: Self
pub const FE_CAN_QPSK: Self
Supports QPSK modulation
Sourcepub const FE_CAN_QAM_16: Self
pub const FE_CAN_QAM_16: Self
Supports 16-QAM modulation
Sourcepub const FE_CAN_QAM_32: Self
pub const FE_CAN_QAM_32: Self
Supports 32-QAM modulation
Sourcepub const FE_CAN_QAM_64: Self
pub const FE_CAN_QAM_64: Self
Supports 64-QAM modulation
Sourcepub const FE_CAN_QAM_128: Self
pub const FE_CAN_QAM_128: Self
Supports 128-QAM modulation
Sourcepub const FE_CAN_QAM_256: Self
pub const FE_CAN_QAM_256: Self
Supports 256-QAM modulation
Sourcepub const FE_CAN_QAM_AUTO: Self
pub const FE_CAN_QAM_AUTO: Self
Can auto-detect QAM modulation
Sourcepub const FE_CAN_TRANSMISSION_MODE_AUTO: Self
pub const FE_CAN_TRANSMISSION_MODE_AUTO: Self
Can auto-detect transmission mode
Sourcepub const FE_CAN_BANDWIDTH_AUTO: Self
pub const FE_CAN_BANDWIDTH_AUTO: Self
Can auto-detect bandwidth
Sourcepub const FE_CAN_GUARD_INTERVAL_AUTO: Self
pub const FE_CAN_GUARD_INTERVAL_AUTO: Self
Can auto-detect guard interval
Sourcepub const FE_CAN_HIERARCHY_AUTO: Self
pub const FE_CAN_HIERARCHY_AUTO: Self
Can auto-detect hierarchy
Sourcepub const FE_CAN_8VSB: Self
pub const FE_CAN_8VSB: Self
Supports 8-VSB modulation
Sourcepub const FE_CAN_16VSB: Self
pub const FE_CAN_16VSB: Self
Supports 16-VSB modulation
Sourcepub const FE_HAS_EXTENDED_CAPS: Self
pub const FE_HAS_EXTENDED_CAPS: Self
Unused
Sourcepub const FE_CAN_MULTISTREAM: Self
pub const FE_CAN_MULTISTREAM: Self
Supports multistream filtering
Sourcepub const FE_CAN_TURBO_FEC: Self
pub const FE_CAN_TURBO_FEC: Self
Supports “turbo FEC” modulation
Sourcepub const FE_CAN_2G_MODULATION: Self
pub const FE_CAN_2G_MODULATION: Self
Supports “2nd generation” modulation, e. g. DVB-S2, DVB-T2, DVB-C2
Sourcepub const FE_NEEDS_BENDING: Self
pub const FE_NEEDS_BENDING: Self
Unused
Sourcepub const FE_CAN_RECOVER: Self
pub const FE_CAN_RECOVER: Self
Can recover from a cable unplug automatically
Sourcepub const FE_CAN_MUTE_TS: Self
pub const FE_CAN_MUTE_TS: Self
Can stop spurious TS data output
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> Self
pub const unsafe fn from_bits_unchecked(bits: u32) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.